Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(22)

Unified Diff: third_party/WebKit/public/web/WebWidgetClient.h

Issue 2596193002: Clean up names and remove unnecessary parameter (Closed)
Patch Set: change show_ime to show_virtual_keyboard in the renderer Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/public/web/WebWidgetClient.h
diff --git a/third_party/WebKit/public/web/WebWidgetClient.h b/third_party/WebKit/public/web/WebWidgetClient.h
index 60ac185aaca6cf916239fdeee79ba0c63cd583d8..5d9ec6cd544077f7af743e1da04b86679456b625 100644
--- a/third_party/WebKit/public/web/WebWidgetClient.h
+++ b/third_party/WebKit/public/web/WebWidgetClient.h
@@ -146,8 +146,8 @@ class WebWidgetClient {
// the embedder of the touch actions that are permitted for this touch.
virtual void setTouchAction(WebTouchAction touchAction) {}
- // Request the browser to show the IME for current input type.
- virtual void showImeIfNeeded() {}
+ // Request the browser to show virtual keyboard for current input type.
+ virtual void showVirtualKeyboard() {}
// Request that the browser show a UI for an unhandled tap, if needed.
// Invoked during the handling of a GestureTap input event whenever the
« content/renderer/render_widget.cc ('K') | « third_party/WebKit/public/web/WebViewClient.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698